==> xixiBlog-0.13.zip: xixiBlog/xoops_version.php <==
<?php
/**
@file
@brief xoops  module ե
@author minahito
*/

$modversion['name'] = _MI_XIXIBLOG_NAME;
$modversion['version'] = 0.13;
$modversion['description'] = _MI_XIXIBLOG_DESC;

$modversion['credits'] = "minahito";
$modversion['author'] = "minahito" ;
$modversion['license'] = "BSD see LICENSE";
$modversion['official'] = 0;
$modversion['image'] = "images/xixiBlog.gif";
$modversion['dirname'] = "xixiBlog";


// Template
$modversion['use_smarty'] = 1;
$modversion['templates'][0]['file'] = 'xixiblog_index.html';
$modversion['templates'][0]['description'] = '';
$modversion['templates'][1]['file'] = 'xixiblog_blog.html';
$modversion['templates'][1]['description'] = '';
$modversion['templates'][2]['file'] = 'xixiblog_detail.html';
$modversion['templates'][2]['description'] = '';
$modversion['templates'][3]['file'] = 'xixiblog_item.html';
$modversion['templates'][3]['description'] = '';
$modversion['templates'][4]['file'] = 'xixiblog_comments.html';
$modversion['templates'][4]['description'] = 'template for viewcomments.php';


// Sql
$modversion['sqlfile']['mysql'] = "sql/mysql.sql";

$modversion['tables'][0] = "xixiblog_blog";
$modversion['tables'][1] = "xixiblog_comment";
$modversion['tables'][2] = "xixiblog_trackback";
$modversion['tables'][3] = "xixiblog_head";
$modversion['tables'][4] = "xixiblog_calender";

// Block
$modversion['blocks'][1]['file'] = "xixiblog_calendar.php";
$modversion['blocks'][1]['name'] = _MI_XIXIBLOG_BNAME1;
$modversion['blocks'][1]['show_func'] = "b_xixiblog_calendar_show";
$modversion['blocks'][1]['template'] = 'xixiblog_block_calendar.html';

$modversion['blocks'][2]['file'] = "xixiblog_month.php";
$modversion['blocks'][2]['name'] = _MI_XIXIBLOG_BNAME2;
$modversion['blocks'][2]['show_func'] = "b_xixiblog_month_show";
$modversion['blocks'][2]['template'] = 'xixiblog_block_month.html';

$modversion['blocks'][3]['file'] = "xixiblog_comments.php";
$modversion['blocks'][3]['name'] = _MI_XIXIBLOG_BNAME3;
$modversion['blocks'][3]['show_func'] = "b_xixiblog_comments_show";
$modversion['blocks'][3]['template'] = 'xixiblog_block_comments.html';

$modversion['blocks'][4]['file'] = "xixiblog_profile.php";
$modversion['blocks'][4]['name'] = _MI_XIXIBLOG_BNAME4;
$modversion['blocks'][4]['show_func'] = "b_xixiblog_profile_show";
$modversion['blocks'][4]['template'] = 'xixiblog_block_profile.html';

$modversion['blocks'][5]['file'] = "xixiblog_lastest.php";
$modversion['blocks'][5]['name'] = _MI_XIXIBLOG_BNAME5;
$modversion['blocks'][5]['show_func'] = "b_xixiblog_lastest_show";
$modversion['blocks'][5]['template'] = 'xixiblog_block_lastest.html';
$modversion['blocks'][5]['edit_func'] = 'b_xixiblog_lastest_edit';
$modversion['blocks'][5]['options'] = "10";

// Admin
$modversion['hasAdmin'] = 1;
$modversion['adminindex'] = "admin/index.php";
$modversion['adminmenu'] = "admin/menu.php";


// Menu
$modversion['hasMain'] = 1;
if(strpos($_SERVER['SCRIPT_NAME'],$modversion['dirname'])!==false) {
	require_once dirname(__FILE__)."/../exFrame/frameloader.php";
	require_once "xoops/perm.php";
	if(exPerm::Guard('post_blog'))
		$modversion['sub'][]=array('name'=>_MI_XIXIBLOG_SUBMENU1,'url'=>'submit.php');
	if(exPerm::Guard('edit_head_mine'))
		$modversion['sub'][]=array('name'=>_MI_XIXIBLOG_SUBMENU2,'url'=>'head.php');
}

// Config
$modversion['config'][1]['name']='rss_mode';
$modversion['config'][1]['title']='_MI_XIXIBLOG_RSS';
$modversion['config'][1]['description']='_MI_XIXIBLOG_RSS_DESC';
$modversion['config'][1]['formtype']='select';
$modversion['config'][1]['valuetype']='int';
$modversion['config'][1]['default']=0;
$modversion['config'][1]['options']=array(_MI_XIXIBLOG_RSS_NO=>0,_MI_XIXIBLOG_RSS_PHP=>1,_MI_XIXIBLOG_RSS_FILE=>2);

$modversion['config'][2]['name']='rss_directory';
$modversion['config'][2]['title']='_MI_XIXIBLOG_RSS_DIRECTORY';
$modversion['config'][2]['description']='_MI_XIXIBLOG_RSS_DIRECTORY_DESC';
$modversion['config'][2]['formtype']='textbox';
$modversion['config'][2]['valuetype']='text';
$modversion['config'][2]['default']="/modules/xixiBlog/rss";

$modversion['config'][3]['name']='rss_prefix';
$modversion['config'][3]['title']='_MI_XIXIBLOG_RSS_PREFIX';
$modversion['config'][3]['description']='_MI_XIXIBLOG_RSS_PREFIX_DESC';
$modversion['config'][3]['formtype']='textbox';
$modversion['config'][3]['valuetype']='text';
$modversion['config'][3]['default']="xixiblog";

?>

==> xixiBlog-0.15.zip: xixiBlog/xoops_version.php <==
<?php
/**
@file
@brief xoops  module ե
@author minahito
*/

$modversion['name'] = _MI_XIXIBLOG_NAME;
$modversion['version'] = 0.15;
$modversion['description'] = _MI_XIXIBLOG_DESC;

$modversion['credits'] = "minahito";
$modversion['author'] = "minahito" ;
$modversion['license'] = "BSD see LICENSE";
$modversion['official'] = 0;
$modversion['image'] = "images/xixiBlog.gif";
$modversion['dirname'] = "xixiBlog";


// Template
$modversion['use_smarty'] = 1;
$modversion['templates'][0]['file'] = 'xixiblog_index.html';
$modversion['templates'][0]['description'] = '';
$modversion['templates'][1]['file'] = 'xixiblog_blog.html';
$modversion['templates'][1]['description'] = '';
$modversion['templates'][2]['file'] = 'xixiblog_detail.html';
$modversion['templates'][2]['description'] = '';
$modversion['templates'][3]['file'] = 'xixiblog_item.html';
$modversion['templates'][3]['description'] = '';
$modversion['templates'][4]['file'] = 'xixiblog_comments.html';
$modversion['templates'][4]['description'] = 'template for viewcomments.php';


// Sql
$modversion['sqlfile']['mysql'] = "sql/mysql.sql";

$modversion['tables'][0] = "xixiblog_blog";
$modversion['tables'][1] = "xixiblog_comment";
$modversion['tables'][2] = "xixiblog_trackback";
$modversion['tables'][3] = "xixiblog_head";
$modversion['tables'][4] = "xixiblog_calender";

// Block
$modversion['blocks'][1]['file'] = "xixiblog_calendar.php";
$modversion['blocks'][1]['name'] = _MI_XIXIBLOG_BNAME1;
$modversion['blocks'][1]['show_func'] = "b_xixiblog_calendar_show";
$modversion['blocks'][1]['template'] = 'xixiblog_block_calendar.html';

$modversion['blocks'][2]['file'] = "xixiblog_month.php";
$modversion['blocks'][2]['name'] = _MI_XIXIBLOG_BNAME2;
$modversion['blocks'][2]['show_func'] = "b_xixiblog_month_show";
$modversion['blocks'][2]['template'] = 'xixiblog_block_month.html';

$modversion['blocks'][3]['file'] = "xixiblog_comments.php";
$modversion['blocks'][3]['name'] = _MI_XIXIBLOG_BNAME3;
$modversion['blocks'][3]['show_func'] = "b_xixiblog_comments_show";
$modversion['blocks'][3]['template'] = 'xixiblog_block_comments.html';

$modversion['blocks'][4]['file'] = "xixiblog_profile.php";
$modversion['blocks'][4]['name'] = _MI_XIXIBLOG_BNAME4;
$modversion['blocks'][4]['show_func'] = "b_xixiblog_profile_show";
$modversion['blocks'][4]['template'] = 'xixiblog_block_profile.html';

$modversion['blocks'][5]['file'] = "xixiblog_lastest.php";
$modversion['blocks'][5]['name'] = _MI_XIXIBLOG_BNAME5;
$modversion['blocks'][5]['show_func'] = "b_xixiblog_lastest_show";
$modversion['blocks'][5]['template'] = 'xixiblog_block_lastest.html';
$modversion['blocks'][5]['edit_func'] = 'b_xixiblog_lastest_edit';
$modversion['blocks'][5]['options'] = "10";

// Admin
$modversion['hasAdmin'] = 1;
$modversion['adminindex'] = "admin/index.php";
$modversion['adminmenu'] = "admin/menu.php";


// Menu
$modversion['hasMain'] = 1;
if(strpos($_SERVER['SCRIPT_NAME'],$modversion['dirname'])!==false) {
	require_once dirname(__FILE__)."/../exFrame/frameloader.php";
	require_once "xoops/perm.php";
	if(exPerm::Guard('post_blog'))
		$modversion['sub'][]=array('name'=>_MI_XIXIBLOG_SUBMENU1,'url'=>'submit.php');
	if(exPerm::Guard('edit_head_mine'))
		$modversion['sub'][]=array('name'=>_MI_XIXIBLOG_SUBMENU2,'url'=>'head.php');
}

// Config
$modversion['config'][1]['name']='rss_mode';
$modversion['config'][1]['title']='_MI_XIXIBLOG_RSS';
$modversion['config'][1]['description']='_MI_XIXIBLOG_RSS_DESC';
$modversion['config'][1]['formtype']='select';
$modversion['config'][1]['valuetype']='int';
$modversion['config'][1]['default']=0;
$modversion['config'][1]['options']=array(_MI_XIXIBLOG_RSS_NO=>0,_MI_XIXIBLOG_RSS_PHP=>1,_MI_XIXIBLOG_RSS_FILE=>2);

$modversion['config'][2]['name']='rss_directory';
$modversion['config'][2]['title']='_MI_XIXIBLOG_RSS_DIRECTORY';
$modversion['config'][2]['description']='_MI_XIXIBLOG_RSS_DIRECTORY_DESC';
$modversion['config'][2]['formtype']='textbox';
$modversion['config'][2]['valuetype']='text';
$modversion['config'][2]['default']="/modules/xixiBlog/rss";

$modversion['config'][3]['name']='rss_prefix';
$modversion['config'][3]['title']='_MI_XIXIBLOG_RSS_PREFIX';
$modversion['config'][3]['description']='_MI_XIXIBLOG_RSS_PREFIX_DESC';
$modversion['config'][3]['formtype']='textbox';
$modversion['config'][3]['valuetype']='text';
$modversion['config'][3]['default']="xixiblog";

$modversion['config'][4]['name']='rss_type';
$modversion['config'][4]['title']='_MI_XIXIBLOG_RSS_TYPE';
$modversion['config'][4]['description']='_MI_XIXIBLOG_RSS_TYPE_DESC';
$modversion['config'][4]['formtype']='select';
$modversion['config'][4]['valuetype']='int';
$modversion['config'][4]['default']=2;
$modversion['config'][4]['options']=array(_MI_XIXIBLOG_RSS_TYPE_1=>1,_MI_XIXIBLOG_RSS_TYPE_2=>2);


// Search
$modversion['hasSearch'] = 1;
$modversion['search']['file'] = "include/search.inc.php";
$modversion['search']['func'] = "xixiblog_search";

?>
